darkhistory.physics.get_optical_depth — DarkHistory documentation

# darkhistory.physics.get_optical_depth

`darkhistory.physics.` `get_optical_depth`(rs_vec, xe_vec)

  Computes the optical depth given an ionization history.

  Parameters: | rs_vec : ndarray Redshift (1+z). xe_vec : ndarray Free electron fraction xe = ne/nH.
  Returns: | float The optical depth.

#### Previous topic

darkhistory.physics.xHeII_std

#### Next topic

darkhistory.physics.inj_rate

### This Page

Show Source